/******************************************************************
Archivo Menusero.js
Sistema Propano
"Dale gas..."
Autor: Adrian Kosmaczewski
Fecha: 04 de junio de 2004
Version: 1.0


Sistema Propano - Un sistema simple de gestion de contenidos web.
Copyright (C) 2004 - Adrian Kosmaczewski

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

NeXT, the NeXT Cube 	Logo, Objective-C and other related names
are trademarks of NeXT Software Inc. and/or Apple Computer Inc.

For more information please refer to:
http://www.apple.com/legal/nexttmlist.html
*/

/******************************************************************
Clase Menusero
Esta clase se ocupa de administrar la aparicion, desaparicion y posicionamiento 
en la pantalla de los menues de la interfaz grafica del sistema Propano.

Al contrario de las ventanas de la clase Ventana, que son creadas por
el Vidriero en el browser del cliente, los menues son creados en el 
servidor mediante una transformacion XSLT. Una vez que esto se efectua, 
se necesita registrar los correspondientes llamados al Menusero para 
que este los administre.

Este es un ejemplo de uso; supongamos que los DIV que representan los
menues ya han sido dispuestos en la pagina:

	<script language="JavaScript">
	
	// Creacion de menues
	Menusero.instancia.crearMenuPrincipal('Menu');
	Menusero.instancia.crearSubMenu('Archivo', 'Menu');
	Menusero.instancia.crearSubMenu('Edicion', 'Menu');
	Menusero.instancia.crearSubMenu('Vista', 'Menu');
	Menusero.instancia.crearSubMenu('Ventanas', 'Menu');
	Menusero.instancia.crearSubMenu('Ayuda', 'Menu');
	
	</script>

Proposito: Constructor. Crea y mantiene una referencia al menu principal, que
           a su vez tiene referencias a todos sus submenues.
Entrada:   Ninguna.
Salida:    Ninguna.
*/
function Menusero()
{
	var oMenuPrincipal = null;
	
	/*
	Proposito: Crea el menu principal al cual esta asociado el Menusero.
	Entrada:   El nombre del menu.
	Salida:    Ninguna.
	*/
	this.crearMenuPrincipal = function(sNombre)
	{
		oMenuPrincipal = new Menu(sNombre);
		oMenuPrincipal.establecerComoMenuPrincipal(true);
	}

	/*
	Proposito: Crea un submenu
	Entrada:   El nombre del menu, y el nombre del que sera su padre.
	Salida:    Ninguna.
	*/
	this.crearSubMenu = function(sNombre, sNombreMenuPadre)
	{
		if (oMenuPrincipal)
		{
			var bResultado = oMenuPrincipal.crearSubMenu(sNombre, sNombreMenuPadre);
		}
	}
	
	/*
	Proposito: Hides the specified menu (if not currently hidden).
	Entrada:	The string id of the menu to display.
	Salida:	 none.
	*/
	this.ocultarMenu = function(sId)
	{
		var bResultado = oMenuPrincipal.ocultar(sId);
	}

	/*
	Proposito: Shows the specified menu (if not currently visible).
	Entrada:	The string id of the menu to display.
	Salida:	 none.
	*/
	this.mostrarMenu = function(sId)
	{
		var bResultado = oMenuPrincipal.mostrarMenu(sId);
	}
	
	this.ocultarTodos = function()
	{
		oMenuPrincipal.ocultarTodos();
	}
}

Menusero.instancia = new Menusero();
Menusero.SUFIJO_PANEL = "_PanelMenu";
Menusero.SUFIJO_CELDA = "_ItemMenu";
Menusero.ESTILO_PARA_RESALTAR = "LineaCuandoPasaElMouse";
Menusero.ESTILO_NORMAL = "Linea";
Menusero.SEGUNDOS_PARA_CIERRE_AUTOMATICO = 5;

/******************************************************************
Clase Menu
Esta es una clase privada que es usada por el Menusero para encapsular
el acceso a los <DIV> que representan los menues. No se acceden a las instancias
de esta clase directamente, sino a traves del Menusero.

Proposito: Constructor. Inicializa las variables, y establece la referencia
           a la clase "padre" y a la coleccion de submenues.
Entrada:	   Una cadena con el nombre del menu y una referencia a su "padre" en la
           arborescencia de menues.
Salida:    Ninguna.
*/
function Menu(sNombreParametro, oMenuPadreParametro)
{
	var sNombre = sNombreParametro;
	var oDiv = document.getElementById(sNombre + Menusero.SUFIJO_PANEL);
	var oTD = document.getElementById(sNombre + Menusero.SUFIJO_CELDA);
	var oMenuPadre = oMenuPadreParametro;
	var oSubMenuse = {};
	var oTimeouts = {};
	var bVisible = false;
	var bEsMenuPrincipal = false;
	
	/*
	Proposito: Determina si esta instancia es un menu principal.
	Entrada:   Un valor booleano.
	Salida:    Ninguna.
	*/
	this.establecerComoMenuPrincipal = function(bValor)
	{
		bEsMenuPrincipal = bValor;
	}

	/*
	Proposito: Devuelve un valor que indica si esta instancia es un menu principal.
	Entrada:   Ninguna.
	Salida:    Un valor booleano.
	*/	
	this.esMenuPrincipal = function()
	{
		return bEsMenuPrincipal;
	}

	/*
	Proposito: El proceso de creacion de menues es delegativo; el Menusero recibe una
	           orden de apertura; este se la pasa al Menu principal registrado y
	           aquel envia, si necesario, el mismo mensaje a sus menues hijos.
	           Este proceso es repetitivo pero se realiza una sola vez; cuando se
	           crea la estructura de menues despues de la carga de la pagina.
	Entrada:   El nombre del menu que se crea y el nombre del menu padre del mismo.
	Salida:    "true" si se creo satisfactoriamente el menu.
	*/	
	this.crearSubMenu = function(sNombreParametro, sNombrePadre)
	{
		if (sNombre == sNombrePadre)
		{
			oSubMenuse[sNombreParametro] = new Menu(sNombreParametro, this);
			return true;
		}
		else
		{
			var bResultado = false;
			for (var oSubMenu in oSubMenuse)
			{
				bResultado = oSubMenuse[oSubMenu].crearSubMenu(sNombreParametro, sNombrePadre);
				// Si se creo el menu, bloquear el bucle para que no ejecute mas
				if (bResultado)
				{
					break;
				}
			}
			return bResultado;
		}
	}

	/*
	Proposito: Hides all the menus in the collection.
	Entrada:	none.
	Salida:	 none.
	*/
	this.ocultarTodos = function()
	{
		for (var oMenu in oSubMenuse)
		{
			oSubMenuse[oMenu].ocultar(oMenu);
			window.clearTimeout(oTimeouts[oMenu]);
		}
	}

	/*
	Proposito: Muestra el menu. Opera recursivamente ya que el Menusero
	           recibe un pedido de apertura de menu, pero no sabe de quien
	           es hijo, en el caso de sub-sub-submenues...
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	this.mostrarMenu = function(sId)
	{
		if (sId == sNombre)
		{
			oMenuPadre.ocultarTodos();
			this.mover();
			if (oDiv != null)
			{
				if (oDiv.filters && (oDiv.filters.length > 0))
				{
					for (var i = 0; i < oDiv.filters.length; i++)
					{
						oDiv.filters.item(i).Apply();
						oDiv.filters.item(i).Enabled = true;
					}
				}
				oDiv.style.visibility = 'visible';
				oTD.className = Menusero.ESTILO_PARA_RESALTAR;
				bVisible = true;
				
				// Esto es por si alguien abre un menu, lo cierra y enseguida lo
				// vuelve a abrir: si no se elimina el timeout anterior, el menu se 
				// cerraria de inmediato!
				window.clearTimeout(oTimeouts[sNombre]);
				
				// Establece un timeout para que el menu se cierre; este no
				// es el comportamiento estandar del NeXT, pero por ahora, hagamos asi.
				oTimeouts[sNombre] = window.setTimeout("Menusero.instancia.ocultarMenu('" + sNombre + "')", Menusero.SEGUNDOS_PARA_CIERRE_AUTOMATICO * 1000);
				if (oDiv.filters && (oDiv.filters.length > 0))
				{
					for (var i = 0; i < oDiv.filters.length; i++)
					{
						oDiv.filters.item(i).Play();
					}
				}
			}
			return true;
		}
		else
		{
			var bResultado = false;
			for (var oMenu in oSubMenuse)
			{
				bResultado = oSubMenuse[oMenu].mostrarMenu(sId);
				if (bResultado)
				{
					break;
				}
			}
			return bResultado;
		}
	}

	/*
	Proposito: Oculta el menu. Opera recursivamente sobre los 
	           submenues que contiene este menu, para que aquellos 
	           tambien se cierren.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	this.ocultar = function(sId)
	{
		if (sId == sNombre)
		{
			bVisible = false;
			this.ocultarTodos();
			if (oDiv != null)
			{
				if (oDiv.filters && (oDiv.filters.length > 0))
				{
					for (var i = 0; i < oDiv.filters.length; i++)
					{
						oDiv.filters.item(i).Apply();
						oDiv.filters.item(i).Enabled = true;
					}
				}
				oTD.className = Menusero.ESTILO_NORMAL;
				oDiv.style.visibility = 'hidden';
				if (oDiv.filters && (oDiv.filters.length > 0))
				{
					for (var i = 0; i < oDiv.filters.length; i++)
					{
						oDiv.filters.item(i).Play();
					}
				}
			}
			return true;
		}
		else
		{
			var bResultado = false;
			for (var oMenu in oSubMenuse)
			{
				bResultado = oSubMenuse[oMenu].ocultar(sId);
				if (bResultado)
				{
					break;
				}
			}
			return bResultado;
		}
	}
	
	/*
	Proposito: Informa si el menu es visible o no.
	Entrada:   Ninguna.
	Salida:    Un valor booleano, "true" o "false".
	*/
	this.esVisible = function()
	{
		return bVisible;
	}
	
	/*
	Proposito: Coloca el <DIV> del menu donde corresponde al abrirse.
	Entrada:	   Ninguna.
	Salida:	   Ninguna.
	*/
	this.mover = function()
	{
		// Inicialmente los DIV son creados con la posicion (0, 0)
		// Este codigo los coloca a la derecha del menu anterior, a la misma altura.
		oDiv.style.left = (oMenuPadre.posicionX() + oMenuPadre.ancho()).toString() + "px";
		oDiv.style.top = oMenuPadre.posicionY().toString() + "px";
	}

	/*
	Proposito: Devuelve la altura (en pixeles) de la ventana.
	Entrada:   Ninguna.
	Salida:    Un numero entero.
	*/
	this.altura = function()
	{
		return parseInt(oDiv.offsetHeight);
	}

	/*
	Proposito: Devuelve el ancho (en pixeles) de la ventana.
	Entrada:   Ninguna.
	Salida:    Un numero entero.
	*/
	this.ancho = function()
	{
		return parseInt(oDiv.offsetWidth);
	}

	/*
	Proposito: Devuelve la distancia (en pixeles) de la ventana 
	           al borde izquierdo del espacio del browser.
	Entrada:   Ninguna.
	Salida:    Un numero entero.
	*/
	this.posicionX = function()
	{
		return parseInt(oDiv.offsetLeft);
	}

	/*
	Proposito: Devuelve la distancia (en pixeles) de la ventana 
	           al borde superior del espacio del browser.
	Entrada:   Ninguna.
	Salida:    Un numero entero.
	*/
	this.posicionY = function()
	{
		return parseInt(oDiv.offsetTop);
	}
}

