/******************************************************************
Archivo Navegador.js
Sistema Propano
"Dale gas..."
Autor: Adrian Kosmaczewski
Fecha: 30 de mayo de 2004
Version: 1.0


Sistema Propano - Un sistema simple de gestion de contenidos web.
Copyright (C) 2004 - Adrian Kosmaczewski

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

NeXT, the NeXT Cube 	Logo, Objective-C and other related names
are trademarks of NeXT Software Inc. and/or Apple Computer Inc.

For more information please refer to:
http://www.apple.com/legal/nexttmlist.html
*/

/******************************************************************
Clase Navegador
Proposito: Esta clase JavaScript encapsula el proceso de navegacion del lado del cliente
en el Sistema Propano. Para aquellos browsers que tienen la posibilidad de instanciar
una clase de tipo XmlHTTPRequest, el sistema realiza pedidos de informacion usando
este mecanismo. En caso de no poseer esta capacidad, se realiza una redireccion
clasica.

Esta clase realiza el chequeo de las posibilidades del navegador solamente en el 
momento de la instanciacion; todos los llamados al metodo abrirDocumento de esta clase 
se realizan luego delegando la responsabilidad a una instancia privada, encapsulada 
dentro de la clase Navegador.

Ejemplo de uso en una pagina HTML:

	<html>
	<head>
		<script language="JavaScript" src="cliente/js/Navegador.js"></script>
	</head>
	
	<body>
	
		<script language="JavaScript">
		function ir()
		{
			Navegador.instancia.abrirDocumento('documento.xml');
		}
		
		Navegador.documentoListo = function()
		{
			var oJavaScript = Navegador.instancia.documentoJS();
			alert(oJavaScript.datos.contenidos);
		};
		</script>
		
	<input type="button" value="Irse de aca" onClick="ir()">
	
	</body>
	</html>
*/
function Navegador()
{
	// Este codigo asegura que solamente pueda existir una sola
	// instancia de esta clase (GOF Singleton pattern)
	if (Navegador.instancia)
	{
		return Navegador.instancia;
	}

	// Definicion y rellenado de la variable que contiene el delegado.
	var oDelegado = null;
	inicializar();

	/*
	Proposito: Delega la apertura del documento especificado.
	Entrada:   Una cadena de caracteres representando un URL valido
	Salida:    Ninguna.
	*/
	this.abrirDocumento = function(sURL)
	{
		oDelegado.abrirDocumento("index.php/" + sURL);
	}

	/*
	Proposito: Devuelve el status HTTP del pedido de informacion.
	Entrada:   Ninguna
	Salida:    Un entero con uno de los siguientes valores:
	           100 Continue
	           101 Switching protocols
	           200 OK
	           201 Created
	           202 Accepted
	           203 Non-Authoritative Information
	           204 No Content
	           205 Reset Content
	           206 Partial Content
	           300 Multiple Choices
	           301 Moved Permanently
	           302 Found
	           303 See Other
	           304 Not Modified
	           305 Use Proxy
	           307 Temporary Redirect
	           400 Bad Request
	           401 Unauthorized
	           402 Payment Required
	           403 Forbidden
	           404 Not Found
	           405 Method Not Allowed
	           406 Not Acceptable
	           407 Proxy Authentication Required
	           408 Request Timeout
	           409 Conflict
	           410 Gone
	           411 Length Required
	           412 Precondition Failed
	           413 Request Entity Too Large
	           414 Request-URI Too Long
	           415 Unsupported Media Type
	           416 Requested Range Not Suitable
	           417 Expectation Failed
	           500 Internal Server Error
	           501 Not Implemented
	           502 Bad Gateway
	           503 Service Unavailable
	           504 Gateway Timeout
	           505 HTTP Version Not Supported
	*/
	this.httpStatus = function()
	{
		return oDelegado.httpStatus();
	}
	
	/*
	Proposito: Devuelve el estado del delegado.
	Entrada:   Ninguna.
	Salida:    Un valor numerico entero representando lo siguiente:
	           0 = no inicializado
	           1 = cargando informacion
	           2 = cargado
	           3 = interactivo
	           4 = operacion terminada
	Nota:      Cada vez que el estado cambia, se realiza automaticamente
	           un llamado a la funcion global "procesarCambioDeEstado" definida
	           al final de este modulo.
	*/
	this.estadoActual = function()
	{
		return oDelegado.estadoActual();
	}
	
	/*
	Proposito: Devuelve el texto del URL solicitado.
	Entrada:   Ninguna
	Salida:    Una cadena de texto con el texto del URL solicitado.
	*/
	this.documentoTexto = function()
	{
		return oDelegado.documentoTexto();
	}

	/*
	Proposito: Devuelve el objeto XML con los contenidos del URL solicitado.
	Entrada:   Ninguna
	Salida:    Un objeto XML DOM.
	*/
	this.documentoXML = function()
	{
		return oDelegado.documentoXML();
	}
	
	/*
	Proposito: Devuelve un objeto JavaScript con los contenidos del URL solicitado.
	Entrada:   Ninguna
	Salida:    Un objeto (diccionario asociativo) JavaScript.
	*/
	this.documentoJS = function()
	{
		return crearObjetoDeXML(this.documentoXML().documentElement);
	}

	/*
	Proposito: inicializa la instancia.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	function inicializar()
	{
		var bMozilla = (window.XMLHttpRequest) ? true : false;
		var bInternetExplorer = (window.ActiveXObject) ? true : false;
		
		// Atencion: si los constructores de DelegadoMozilla o DelegadoInternetExplorer
		// lanzan una excepcion, construir una instancia de DelegadoSimple para poder
		// ofrecer un medio de navegacion para los browsers como Opera que no 
		// tienen soporte para XMLHttpRequest.
		try
		{
			if (bMozilla)
			{
				oDelegado = new DelegadoMozilla();
				return;
			}
			
			if (bInternetExplorer)
			{
				oDelegado = new DelegadoInternetExplorer();
				return;
			}

			oDelegado = new DelegadoSimple();
		}
		catch (e)
		{
			oDelegado = new DelegadoSimple();
		}
	}
	
	/*
	Proposito: Transforma un nodo XML en un diccionario asociativo JavaScript.
	Entrada:   Un nodo XML
	Salida:    Un objeto JavaScript.
	Notas:     Este metodo se llama a si mismo recursivamente para crear
	           los objetos que representan los subelementos del arbol XML original:
				           
				<documento id="00001">
				    <metadatos>
				        <titulo>Documento Test</titulo>
				        <autor>Adrian Kosmaczewski</autor>
				    </metadatos>
				</documento>
				
				
				var documento = {
					metadatos: {
						titulo: "Documento Test";
						autor: "Adrian Kosmaczewski";
					};
				};
				
				Luego se puede acceder a los contenidos del objeto con la sintaxis
				documento['metadatos']['titulo']     o
				documento.metadatos.titulo
	*/
	function crearObjetoDeXML(oNodo)
	{
		var oResultado = {};
		var aNodos = oNodo.childNodes;
		var oNodoActual = null;
		var sNombre = "";
		var iTipoNodo = 0;
		var iLongitud = 0;
	
		for (var i = 0; i < aNodos.length; i++)
		{
			oNodoActual = aNodos[i];
			iTipoNodo = oNodoActual.nodeType;
			sNombre = oNodoActual.nodeName;
			iLongitud = oNodoActual.childNodes.length;
			
			// Solamente considerar el caso en que es un nodo de tipo ELEMENT
			if (iTipoNodo == 1)
			{
				// Si solamente tiene un ninio, entonces es un nodo
				// con texto adentro.
				if (iLongitud == 1)
				{
					// Como el DOM standard no implementa la propiedad "text"
					// (presente en la implementacion IXMLHttpRequest de Microsoft)
					// tenemos que usar esta sintaxis para lograr un resultado similar.
					oResultado[sNombre] = oNodoActual.childNodes[0].nodeValue;
				}
				if (iLongitud > 1)
				{
					// Es un nodo compuesto de subnodos: crear los
					// subobjetos pertinentes.
					oResultado[sNombre] = crearObjetoDeXML(oNodoActual);
				}
			}
		}
		return oResultado;
	}
}

// Definicion de variables de clase
Navegador.instancia = new Navegador();
Navegador.documentoListo = null;
Navegador.error = null;

/******************************************************************
Clase DelegadoSimple
Esta clase tiene la misma interfaz que los otros delegados, y
en vez de usar un objeto XMLHttpRequest simplemente realiza un 
redireccionamiento "clasico" hacia el URL solicitado. Los demas metodos 
simplemente devuelven null cuando se los llama.
*/
function DelegadoSimple()
{
	this.abrirDocumento = function(sURL)
	{
		location.href = sURL;
	}
	
	this.httpStatus = function()
	{
		return null;
	}
		
	this.estadoActual = function()
	{
		return null;
	}
	
	this.documentoTexto = function()
	{
		return null;
	}
	
	this.documentoXML = function()
	{
		return null;
	}	
}

/******************************************************************
Clase DelegadoInternetExplorer
Encapsula logica para navegacion basada en el componente MSXML que 
solamente existe en las distribuciones Windows de Internet Explorer, 
desde la version 5.5 en adelante
*/
function DelegadoInternetExplorer()
{
	var oMotor = new ActiveXObject("Microsoft.XMLHTTP");

	// Si no se creo la instancia de XMLHttpRequest, interrumpir
	// el proceso actual con una excepcion. Esto hara que se
	// instancie un DelegadoSimple en el constructor de Navegador.
	if (oMotor == null)
	{
		throw new Error();
	}

	this.abrirDocumento = function(sURL)
	{
		// Setear el proceso de retrollamada
		// Esta linea de codigo tiene que estar aca, ya que
		// al final del proceso de comunicacion el componente pierde
		// la referencia al metodo de retrollamada.
		oMotor.onreadystatechange = procesarCambioDeEstado;
		oMotor.open("GET", sURL, true);
		oMotor.send();
	}

	this.httpStatus = function()
	{
		try
		{
			return oMotor.status;
		}
		catch (e)
		{
			// Por alguna razon... este llamado devuelve un
			// error SALVO cuando el codigo es 200...
		}
	}
		
	this.estadoActual = function()
	{
		return oMotor.readyState;
	}
	
	this.documentoTexto = function()
	{
		return oMotor.responseText;
	}
	
	this.documentoXML = function()
	{
		return oMotor.responseXML;
	}	
}

/******************************************************************
Clase DelegadoMozilla
Esta clase usa el objeto XMLHttpRequest que esta presente en todas las 
versiones de Mozilla y en el navegador Safari de Apple, y que posee la 
misma funcionalidad que el objeto MSXML de Microsoft Internet Explorer.
*/
function DelegadoMozilla()
{
	var oMotor = new XMLHttpRequest();
	
	// Si no se creo la instancia de XMLHttpRequest, interrumpir
	// el proceso actual con una excepcion. Esto hara que se
	// instancie un DelegadoSimple en el constructor de Navegador.
	if (oMotor == null)
	{
		throw new Error();
	}
	
	this.abrirDocumento = function(sURL)
	{
		// Setear el proceso de retrollamada
		// Esta linea de codigo tiene que estar aca, ya que
		// al final del proceso de comunicacion el componente pierde
		// la referencia al metodo de retrollamada.
		oMotor.onreadystatechange = procesarCambioDeEstado;
		oMotor.open("GET", sURL, true);
		oMotor.send(null);
	}

	this.httpStatus = function()
	{
		try
		{
			return oMotor.status;
		}
		catch (e)
		{
			// Por alguna razon... este llamado devuelve un
			// error SALVO cuando el codigo es 200...
			// Esto sucede en Mozilla y en IE Windows
		}
	}
		
	this.estadoActual = function()
	{
		return oMotor.readyState;
	}
	
	this.documentoTexto = function()
	{
		return oMotor.responseText;
	}
	
	this.documentoXML = function()
	{
		return oMotor.responseXML;
	}	
}

/******************************************************************
Proposito: Esta funcion es llamada por instancias de DelegadoMozilla o DelegadoInternetExplorer
           cuando sucede un cambio en el estado del motor de conexion interno.
Entrada:   Ninguno.
Salida:    Ninguna.
Notas:     Esta funcion no puede ser definida como metodo de instancia en el
           Navegador, por razones de arquitectura del lenguaje JavaScript. Por eso se la
           define como una funcion global, que hace referencia a la instancia de
           Navegador.
*/
function procesarCambioDeEstado() 
{
	var estado = Navegador.instancia.estadoActual();
	var httpStatus = Navegador.instancia.httpStatus();

	// Solamente ocuparse del estado 4 (documento listo)
	if (estado == 4)
	{
		if (httpStatus == 200)
		{
			if (Navegador.documentoListo)
			{
				Navegador.documentoListo();
			}
		}
		else
		{
			if (Navegador.error)
			{
				Navegador.error();
			}
		}
	}
}
