/******************************************************************
Archivo Vidriero.js
Sistema Propano
"Dale gas..."
Autor: Adrian Kosmaczewski
Fecha: 30 de mayo de 2004
Version: 1.0


Sistema Propano - Un sistema simple de gestion de contenidos web.
Copyright (C) 2004 - Adrian Kosmaczewski

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

NeXT, the NeXT Cube 	Logo, Objective-C and other related names
are trademarks of NeXT Software Inc. and/or Apple Computer Inc.

For more information please refer to:
http://www.apple.com/legal/nexttmlist.html
*/

/******************************************************************
Clase Vidriero
Proposito: esta clase tiene el rol de administrador de ventanas en la pagina.
Es decir, que toda apertura, cierre, refrescado de contenidos de la misma
pasara por llamados a esta clase. Existe solamente un Vidriero por pagina
("GOF Singleton Pattern", como el Navegador).

Los nombres de los metodos son (creo yo) bastante elocuentes    :)
*/
function Vidriero()
{
	// Chequeo de que solamente existe una instancia de esta clase
	if (Vidriero.instancia)
	{
		return Vidriero.instancia;
	}
	
	// Esta variable privada mantiene la coleccion de ventanas administradas.
	var oVentanas = {};
	
	// Esta variable privada mantiene la cantidad total de ventanas administradas
	var iCantidad = 0;

	// Esta variable privada mantiene el nivel Z (vertical) en que se apilan las ventanas
	var zIndexTop = 10;
	
	var iPosicionProximaVentana = 0;
	
	/*
	Proposito: Activa una ventana cuando se cierra o se achica otra. Esto es para que
	           siempre haya una ventana activa para el usuario.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	this.activarProximaVentana = function()
	{
		var oTemp = null;
		for (var oVentana in oVentanas)
		{
			oTemp = oVentanas[oVentana];
			if (oTemp.esVisible() && !oTemp.estaAchicada())
			{
				this.ponerEnPrimerPlano(oTemp.obtenerNombre());
				break;
			}
		}
	}
	
	/*
	Proposito: Abre la ventana especificada en el parametro; si la ventana ya existe
	           en la coleccion, simplemente le envia un mensaje de apertura;
	           si no existe una ventana con el nombre solicitado, se crea una nueva ventana.
	Entrada:   Una cadena de texto con un nombre de ventana.
	Salida:    Ninguna.
	*/	
	this.abrirVentana = function(sNombre)
	{
		var oVentana = oVentanas[sNombre];
		if (oVentana)
		{
			oVentana.abrir();
			if (oVentana.estaAchicada())
			{
				oVentana.agrandar();
			}
		}
		else
		{
			// Crear una nueva ventana, agregarla a la coleccion, aumentar
			// el contador de ventanas y moverla para que quede posicionada
			// correctamente
			var objNuevaVentana = new Ventana(sNombre);
			objNuevaVentana.cambiarTamanio(500, 500);
			oVentanas[sNombre] = objNuevaVentana;
			objNuevaVentana.moverHacia(23 * iPosicionProximaVentana + 150, 23 * iPosicionProximaVentana + 10);
			iCantidad++;
			iPosicionProximaVentana++;
			
			// Verificar que la ventana no es mas alta o mas ancha de lo debido
			if (((objNuevaVentana.altura() + objNuevaVentana.posicionY()) > Lienzo.instancia.altoPantalla()) || 
				((objNuevaVentana.ancho() + objNuevaVentana.posicionX()) > Lienzo.instancia.anchoPantalla()))
			{
				iPosicionProximaVentana = 0;
			}
		}
		this.ponerEnPrimerPlano(sNombre);
	}

	/*
	Proposito: Reduce la ventana cuyo nombre se pasa en parametro.
	Entrada:   Una cadena de texto con un nombre de ventana.
	Salida:    Ninguna.
	*/
	this.achicarVentana = function(sNombre)
	{
		var oVentana = oVentanas[sNombre];
		if (oVentana)
		{
			oVentana.achicar();
			this.activarProximaVentana();
		}
	}

	/*
	Proposito: Agranda la ventana cuyo nombre se pasa en parametro.
	Entrada:   Una cadena de texto con un nombre de ventana.
	Salida:    Ninguna.
	*/
	this.agrandarVentana = function(sNombre)
	{
		var oVentana = oVentanas[sNombre];
		if (oVentana)
		{
			oVentana.agrandar();
		}
		this.ponerEnPrimerPlano(sNombre);
	}

	/*
	Proposito: Cierra la ventana cuyo nombre se pasa en parametro.
	Entrada:   Una cadena de texto con un nombre de ventana.
	Salida:    Ninguna.
	*/
	this.cerrarVentana = function(sNombre)
	{
		var oVentana = oVentanas[sNombre];
		if (oVentana)
		{
			oVentana.cerrar();
			delete oVentanas[sNombre];
			iCantidad--;
			iPosicionProximaVentana--;
			this.activarProximaVentana();
		}
	}

	/*
	Proposito: Reduce todas las ventanas de la coleccion.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	this.achicarTodas = function()
	{
		for (oVentana in oVentanas)
		{
			oVentanas[oVentana].achicar();
		}
	}

	/*
	Proposito: Agranda todas las ventanas de la coleccion.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	this.agrandarTodas = function()
	{
		for (var oVentana in oVentanas)
		{
			oVentanas[oVentana].agrandar();
		}
	}
	
	/*
	Proposito: Cierra todas las ventanas de la coleccion.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	this.cerrarTodas = function()
	{
		for (var oVentana in oVentanas)
		{
			oVentanas[oVentana].cerrar();
		}
		oVentanas = {};
		iCantidad = 0;
		iPosicionProximaVentana = 0;
		Icono.LINEA_ACTUAL = 1;
		Icono.CANTIDAD_POR_LINEA = 0;
	}
	
	/*
	Proposito: Devuelve una referencia a la ventana especificada.
	Entrada:   Una cadena de texto con un nombre de ventana.
	Salida:    Una referencia a la ventana, o null si no existe la ventana solicitada.
	*/
	this.obtenerVentanaPorNombre = function(sNombre)
	{
		return oVentanas[sNombre];
	}
	
	/*
	Proposito: Devuelve una referencia a la ventana que esta representada
	           por el <DIV> pasado en parametro.
	Entrada:   Una referencia a un objeto DOM <DIV>
	Salida:    El objeto Ventana, si es que este existe.
	*/
	this.obtenerVentanaPorDiv = function(oDiv)
	{
		try
		{
			var sNombre = oDiv.id;
			sNombre = sNombre.substring(Vidriero.PREFIJO_VENTANAS.length, sNombre.length);	
			return this.obtenerVentanaPorNombre(sNombre);
		}
		catch (e)
		{
			return null;
		}
	}
	
	/*
	Proposito: Pone la ventana especificada en primer plano, sobre las demas.
	Entrada:   Una cadena de texto con un nombre de ventana.
	Salida:    Ninguna
	*/
	this.ponerEnPrimerPlano = function(sNombre)
	{
		// Primero mandar todas las ventanas al fondo
		for (var oVentana in oVentanas)
		{
			oVentanas[oVentana].ponerEnPrimerPlano(false);
		}
		
		// Luego mandar la ventana seleccionada al primer plano
		var oVentana = oVentanas[sNombre];
		if (oVentana)
		{
			oVentana.ponerEnNivel(this.aumentarZIndexTop());
			oVentana.ponerEnPrimerPlano(true);
		}
	}
	
	/*
	Proposito: Aumenta el valor de la variable privada zIndexTop.
	           Este metodo es para controlar el aumento de esta variable
	           que se usa para poner a las ventanas encima de todas las otras...
	           El valor que devuelve este metodo se usa tambien para posicionar los iconos.
	Entrada:   Ninguna.
	Salida:    Ninguna
	*/
	this.aumentarZIndexTop = function()
	{
		zIndexTop += 10;
		return zIndexTop;
	}
	
	/*
	Proposito: Devuelve la cantidad de ventanas administradas.
	Entrada:   Ninguna.
	Salida:    El numero (valor entero) de ventanas administradas.
	*/
	this.cantidadDeVentanas = function()
	{
		return iCantidad;
	}
	
	this.obtenerHTMLDeVentana = function(sNombre)
	{
		var oVentana = oVentanas[sNombre];
		if (oVentana)
		{
			return oVentana.obtenerHTML();
		}
		return "";
	}
}

// Instanciacion del Singleton
Vidriero.instancia = new Vidriero();

// Constantes
Vidriero.PREFIJO_VENTANAS = "Ventana_";
Vidriero.PREFIJO_ICONOS = "Icono_";

/******************************************************************
Clase Ventana
Proposito: encapsula la creacion y puesta al dia de un objeto <DIV> en la pantalla con
las siguientes caracteristicas:
1) Tiene tres DIV adentro:
	- Barra de titulo
	- Contenidos
	- Barra inferior
2) La barra de titulo tiene dentro suyo dos <DIV> pequeos, con los botones para cerrar
	y achicar la ventana
3) Tambien existe un "Icono" asociado a la ventana, que aparece cuando esta es "achicada".
	(similar a lo que ocurre en el NeXT o en Windows 3.1). Un doble click sobre el icono
	genera la apertura de la ventana asociada.
4) La ventana puede ser desplazada con el mouse, asi como el icono.
5) La ventana puede ser redimensionada usando la barra inferior gris.
*/
function Ventana(sParametro)
{
	// El nombre de esta ventana. El Vidriero asegura
	// que sean unicos.
	var sNombre = sParametro;
	
	// Una ventana puede estar: 
	// - Visible y Minimizada
	// - Visible y Agrandada
	// - Invisible
	var bMinimizada = false;
	var bVisible = true;
	var bEnPrimerPlano = true;
	
	// Referencia al icono de la ventana; cada ventana tiene uno
	var oIcono = null;
	
	// Variables para los DIV que componen una ventana
	var oDiv = null;
	var oBarraTitulo = null;
	var oContenidos = null;
	var oBarraInferior = null;
	var oImagenCerrar = null;
	var oImagenAchicar = null;
	
	// Informacion de tamanio
	var iAnchoMinimo = 200;
	var iAltoMinimo = 200;
	var iAlto = 0;
	var iAncho = 0;
	var iX = 0;
	var iY = 0;
	
	inicializar();
	
	/*
	Proposito: Permite controlar el cambio de tamanio de la ventana
	Entrada:   El ancho y el alto, en valores numericos, de la ventana
	Salida:    Ninguna.
	*/
	this.cambiarTamanio = function(iNuevoAncho, iNuevoAlto)
	{
		if ((typeof(iNuevoAncho) == "number") && (typeof(iNuevoAlto) == "number"))
		{
			if (iNuevoAncho >= iAnchoMinimo)
			{
				iAncho = iNuevoAncho;
				var sAncho = iNuevoAncho.toString() + "px";
				oDiv.style.width = sAncho;
				oBarraInferior.style.width = sAncho;
				oBarraTitulo.style.width = sAncho;
				oImagenCerrar.style.left = (iNuevoAncho - 15).toString() + "px";
			}
			if (iNuevoAlto >= iAltoMinimo)
			{
				iAlto = iNuevoAlto;
				var sAlto = iNuevoAlto.toString() + "px";
				oDiv.style.height = sAlto;
				oContenidos.style.height = (iNuevoAlto - 31).toString() + "px";
			}
		}
	}
	
	this.obtenerHTML = function()
	{
		return oDiv.innerHTML;
	}
	
	this.altura = function()
	{
		return iAlto;
	}
	
	this.ancho = function()
	{
		return iAncho;
	}

	/*
	Proposito: Realiza el cambio de estilo para que la ventana tenga una apariencia
	           distinta al estar en el primer plano, o en el fondo.
	Entrada:   Una variable booleana: si es true, la ventana se pone en primer plano.
	Salida:    Ninguna.
	*/	
	this.ponerEnPrimerPlano = function(bPoner)
	{
		bEnPrimerPlano = bPoner;
		if (bEnPrimerPlano)
		{
			oBarraTitulo.className = "BarraTitulo";
			
			// Correccion de un bug en Mozilla 1.6 Mac 
			// (ver this.ponerEnNivel() para mas detalles)
			oContenidos.style.overflow = "auto";
			oContenidos.style.overflowX = "hidden";
		}
		else
		{
			oBarraTitulo.className = "BarraTituloNoEnPrimerPlano";

			// Correccion de un bug en Mozilla 1.6 Mac 
			// (ver this.ponerEnNivel() para mas detalles)
			oContenidos.style.overflow = "hidden";
			oContenidos.style.overflowX = "hidden";
		}
	}

	/*
	Proposito: Reduce la ventana. Esto significa que si la ventana
	           no esta ya minimizada y es visible, la misma desaparece y 
	           es reemplazada en la pantalla por el icono asociado.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	this.achicar = function()
	{
		if (!bMinimizada && bVisible)
		{
			oIcono.mostrar();
			oDiv.style.display = 'none';
			bMinimizada = true;
		}
	}
	
	/*
	Proposito: Agranda la ventana. Esto significa que si la ventana
	           esta minimizada y es visible, la misma aparece y 
	           reemplaza en la pantalla al icono asociado.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	this.agrandar = function()
	{
		if (bMinimizada && bVisible)
		{
			oDiv.style.display = 'block';
			oIcono.ocultar();
			bMinimizada = false;
		}
	}
	
	/*
	Proposito: Abre la ventana. Esto significa que si la ventana
	           no es visible, la misma aparece.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	this.abrir = function()
	{
		if (!bVisible)
		{
			oDiv.style.display = 'block';
			oIcono.ocultar();
			bVisible = true;
		}
	}
	
	/*
	Proposito: Cierra la ventana.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	this.cerrar = function()
	{
		if (bVisible)
		{
			oDiv.style.display = 'none';
			oIcono.ocultar();
			oIcono = null;
			bVisible = false;
		}
	}

	/*
	Proposito: Agrega el contenido especificado para que sea visible en el
	           sector intermedio de la ventana.
	Entrada:   El texto que se quiere mostrar.
	Salida:    Ninguna.
	*/	
	this.ponerContenido = function(sContenido)
	{
		oContenidos.innerHTML = sContenido;
	}
	
	/*
	Proposito: Agrega el titulo especificado en la barra superior de la ventana.
	           Si el texto es demasiado largo, lo trunca.
	Entrada:   El texto que se quiere usar como titulo.
	Salida:    Ninguna.
	*/	
	this.ponerTitulo = function(sTitulo)
	{
		oBarraTitulo.innerHTML = sTitulo;
		oIcono.ponerTitulo(sTitulo);
	}

	/*
	Proposito: Mueve la ventana hasta las coordenadas especificadas.
	Entrada:   Los valores X e Y, numericos, necesarios para el movimiento.
	Salida:    Ninguna.
	*/
	this.moverHacia = function(iNuevoX, iNuevoY)
	{
		if ((typeof(iX) == "number") && (typeof(iY) == "number"))
		{
			iX = iNuevoX;
			iY = iNuevoY;
			oDiv.style.left = iX.toString() + "px";
			oDiv.style.top = iY.toString() + "px";
		}
	}

	/*
	Proposito: Devuelve la posicion de la ventana en pixeles.
	Entrada:   Ninguna.
	Salida:    La posicion (numero entero)
	*/	
	this.posicionX = function()
	{
		return iX;
	}
	
	/*
	Proposito: Devuelve la posicion de la ventana en pixeles.
	Entrada:   Ninguna.
	Salida:    La posicion (numero entero)
	*/	
	this.posicionY = function()
	{
		return iY;
	}
	
	/*
	Proposito: Mueve la ventana verticalmente hasta la posicion especificada.
	Entrada:   El valor Z, numerico, necesario para el movimiento.
	Salida:    Ninguna.
	*/
	this.ponerEnNivel = function(iZ)
	{
		if (typeof(iZ) == "number")
		{
			// Este codigo es correcto PERO:
			// en Mozilla 1.6 para Mac, si se superpone una ventana
			// a otra que tiene overflow (es decir, scrollbars), la scrollbar
			// de la ventana de abajo aparece ENCIMA de la barra de titulo
			// de la ventana que supuestamente esta mas arriba! Es un bug, ya que
			// para que esto no suceda, hay que setear "overflow: auto" en la barra
			// lo cual no quiero hacer ya que es la barra de titulo...
			oDiv.style.zIndex = iZ + 1;
			oContenidos.style.zIndex = iZ + 2;
			oBarraTitulo.style.zIndex = iZ + 3;
			oBarraInferior.style.zIndex = iZ + 4;
			oImagenCerrar.style.zIndex = iZ + 5;
			oImagenAchicar.style.zIndex = iZ + 6;
		}
	}
	
	/*
	Proposito: Indica si la ventana esta achicada o no.
	Entrada:   Ninguna.
	Salida:    Un valor booleano (true o false).
	*/
	this.estaAchicada = function()
	{
		return bMinimizada;
	}
	
	/*
	Proposito: Indica si esta ventana es visible o no.
	Entrada:   Ninguna.
	Salida:    Un valor booleano (true o false)
	*/
	this.esVisible = function()
	{
		return bVisible;
	}
	
	/*
	Proposito: Indica si esta ventana esta en primer plano o no.
	Entrada:   Ninguna.
	Salida:    Un valor booleano (true o false)
	*/
	this.estaEnPrimerPlano = function()
	{
		return bEnPrimerPlano;
	}

	/*
	Proposito: Devuelve el nombre de esta ventana.
	Entrada:   Ninguna.
	Salida:    Una cadena de caracteres.
	*/
	this.obtenerNombre = function()
	{
		return sNombre;
	}
	
	/*
	Proposito: Inicializa la instancia en el momento de la creacion.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	function inicializar()
	{
		crearDivs();
		document.body.appendChild(oDiv);
		oIcono = new Icono(sNombre);
	}

	/*
	Proposito: Crea la estructura interna de objetos DIV que forman la ventana.
	           La apariencia de los mismos esta determinada por estilos CSS; notese
	           la ausencia casi total de informacion de apariencia.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	function crearDivs()
	{
		// DIV principal que contiene a los demas
		oDiv = document.createElement('DIV');
		oDiv.className = "Ventana";
		oDiv.id = Vidriero.PREFIJO_VENTANAS + sNombre;
		oDiv.style.left = "0px";
		oDiv.style.top = "0px";
		
		// Barra inferior
		oBarraInferior = document.createElement('DIV');
		oBarraInferior.className = "BarraInferior";
		
		// Barra de titulo, que tambien contiene los botones para agrandar y cerrar
		oBarraTitulo = document.createElement('DIV');
		oBarraTitulo.className = "BarraTitulo";
		oBarraTitulo.id = "Ventana_Titulo_" + sNombre;
		oBarraTitulo.innerHTML = sNombre;

		// Boton para cerrar la ventana
		oImagenCerrar = document.createElement('DIV');
		oImagenCerrar.className = "Cerrar";
		
		// Boton para achicar la ventana
		oImagenAchicar = document.createElement('DIV');
		oImagenAchicar.className = "Achicar";		

		// Esto es para poder agregar el evento dinamicamente 
		// en Internet Explorer...    :(
		if (oImagenAchicar.attachEvent)
		{
			oImagenAchicar.attachEvent("onclick", eventoClickSobreAchicarVentana);
			oImagenCerrar.attachEvent("onclick", eventoClickSobreCerrarVentana);
		}
		else
		{
			oImagenAchicar.setAttribute("onclick", "Vidriero.instancia.achicarVentana('" + sNombre + "');");
			oImagenCerrar.setAttribute("onclick", "Vidriero.instancia.cerrarVentana('" + sNombre + "');");
		}
		
		// Sector para los contenidos de la ventana
		oContenidos = document.createElement('DIV');
		oContenidos.className = "Contenidos";

		// Agregado de los diferentes DIV dentro del DIV maestro				
		oDiv.appendChild(oBarraTitulo);
		oDiv.appendChild(oImagenCerrar);
		oDiv.appendChild(oImagenAchicar);
		oDiv.appendChild(oContenidos);
		oDiv.appendChild(oBarraInferior);
	}
}

/******************************************************************
Clase Icono
Proposito: esta clase representa un icono asociado a una ventana.
*/
function Icono(sNombreParametro)
{
	var sNombre = sNombreParametro;
	var bVisible = false;
	var oDiv = null;
	var oBarraNegra = null;
	
	inicializar();

	/*
	Proposito: Cambia el titulo del icono
	Entrada:   Una cadena de texto con el nuevo titulo.
	Salida:    Ninguna.
	*/	
	this.ponerTitulo = function(sTitulo)
	{
		oBarraNegra.innerHTML = sTitulo;
	}

	/*
	Proposito: Muestra el icono.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	this.mostrar = function()
	{
		oDiv.style.display = 'block';
	}
	
	/*
	Proposito: Oculta el icono.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	this.ocultar = function()
	{
		oDiv.style.display = 'none';
	}
	
	/*
	Proposito: Mueve el icono hasta las coordenadas especificadas.
	Entrada:   Los valores X e Y, numericos, necesarios para el movimiento.
	Salida:    Ninguna.
	*/
	this.moverHacia = function(iX, iY)
	{
		if ((typeof(iX) == "number") && (typeof(iY) == "number"))
		{
			oDiv.style.left = iX.toString() + "px";
			oDiv.style.top = iY.toString() + "px";
		}
	}
	
	/*
	Proposito: Inicializa la instancia durante la creacion.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/	
	function inicializar()
	{
		crearDivs();
		document.body.appendChild(oDiv);
	}
	
	/*
	Proposito: Crea la estructura interna de DIV para mostrar el icono.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	function crearDivs()
	{
		oDiv = document.createElement('DIV');
		oDiv.className = "Icono";
		oDiv.style.display = "none";
		
		var iPosicion = obtenerProximaPosicion();
		var sX = (iPosicion * 65 + 10).toString() + "px";
		var sY = (Lienzo.instancia.altoPantalla() - 65 * Icono.LINEA_ACTUAL).toString() + "px";
		oDiv.style.left = sX;
		oDiv.style.top = sY;

		// La barra negra es un elemento que se usaba en el NeXT para
		// distinguir los iconos de las ventanas reducidas de los de las
		// aplicaciones que estan en el escritorio.
		oBarraNegra = document.createElement('DIV');
		oBarraNegra.className = "IconoBarraNegra";
		oBarraNegra.innerHTML = sNombre;
		oDiv.appendChild(oBarraNegra);
		oDiv.id = Vidriero.PREFIJO_ICONOS + sNombre;
		
		// Esto es para poder agregar el evento dinamicamente 
		// en Internet Explorer...    :(
		if (oDiv.attachEvent)
		{
			oDiv.attachEvent("ondblclick", eventoDobleClickSobreIcono);
		}
		else
		{
			// Si bien aca seria mas correcto usar el metodo addEventListener() 
			// del W3C, resulta que Safari no lo maneja convenientemente;
			// por lo tanto, nos mandamos con esta sintaxis que, aunque fea,
			// funcionan en Mozilla y Safari  :)
			oDiv.setAttribute("ondblclick", "Vidriero.instancia.agrandarVentana('" + sNombre + "');");
		}
	}
	
	function obtenerProximaPosicion()
	{
		var iCantidad = Vidriero.instancia.cantidadDeVentanas();
		
		// Este codigo sirve para "apilar" los iconos convenientemente, para
		// que no depasen los limites de la pantalla.
		if (Icono.CANTIDAD_POR_LINEA == 0)
		{
			if ((iCantidad * 65 + 75) > Lienzo.instancia.anchoPantalla())
			{
				Icono.CANTIDAD_POR_LINEA = iCantidad;
				Icono.LINEA_ACTUAL++;
			}
		}
		if (Icono.CANTIDAD_POR_LINEA != 0)
		{
			if ((iCantidad % Icono.CANTIDAD_POR_LINEA == 0) && (iCantidad != Icono.CANTIDAD_POR_LINEA))
			{
				Icono.LINEA_ACTUAL++;
			}
			iCantidad %= Icono.CANTIDAD_POR_LINEA;
		}
		
		return iCantidad;
	}
}

Icono.CANTIDAD_POR_LINEA = 0;
Icono.LINEA_ACTUAL = 1;

/******************************************************************
Proposito: Funciones globales de callback necesarias para la compatibilidad de 
           este script con Internet Explorer 6 para Windows.
*/
function eventoDobleClickSobreIcono()
{
	var sNombreIcono = event.srcElement.id;
	sNombreIcono = sNombreIcono.substring(Vidriero.PREFIJO_ICONOS.length, sNombreIcono.length);
	Vidriero.instancia.agrandarVentana(sNombreIcono);
}

function eventoClickSobreCerrarVentana()
{
	var sNombre = event.srcElement.parentElement.id;
	sNombre = sNombre.substring(Vidriero.PREFIJO_VENTANAS.length, sNombre.length);
	Vidriero.instancia.cerrarVentana(sNombre);
}

function eventoClickSobreAchicarVentana()
{
	var sNombre = event.srcElement.parentElement.id;
	sNombre = sNombre.substring(Vidriero.PREFIJO_VENTANAS.length, sNombre.length);
	Vidriero.instancia.achicarVentana(sNombre);
}

