# # # # # # # # # # # # # # # # # # # # # # # # # # # 
# 
# Archivo propano.sql
# Sistema Propano
# "Dale gas..."
# Autor: Adrian Kosmaczewski
# Fecha: 05 de junio de 2004
# Version: 1.0
# 
# Sistema Propano - Un sistema simple de gestion de contenidos web.
# Copyright (C) 2004 - Adrian Kosmaczewski
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
# 
# NeXT, the NeXT Cube 	Logo, Objective-C and other related names
# are trademarks of NeXT Software Inc. and/or Apple Computer Inc.
#
# For more information please refer to:
# http://www.apple.com/legal/nexttmlist.html
# 
# # # # # # # # # # # # # # # # # # # # # # # # # # # 
# 
# Este archivo contiene la definicion de la base de datos mysql que se usara
# para guardar los contenidos que se muestran en el Sistema Propano.
# Su estructura es deliberadamente simple:
# 
# - Un articulo puede tener muchas versiones;
# - Un articulo tiene un autor;
# - Pueden existir muchos autores;
# - Una version de un articulo tiene un autor;
# - Se guardan estadisticas de visita por version de articulo;
# 
# Se usan tablas InnoDB para poder definir FOREIGN KEY entre las tablas.
# 
# Las columnas de tipo "timestamp" no guardan datos de tipo NULL, si bien las 
# definiciones de las columnas indican lo contrario.
# Segun la documentacion de MySQL, las columnas TIMESTAMP que reciben un NULL guardan 
# automaticamente la fecha y hora del momento en que se realiza la insercion. 
# http://www.mysql.com/doc/en/Date_and_time_types.html



DROP TABLE IF EXISTS `propano_autores`;
CREATE TABLE `propano_autores` (
	`id` int(10) unsigned NOT NULL auto_increment,
	`nombre` varchar(50) NOT NULL default '',
	`apellido` varchar(50) NOT NULL default '',
	`email` varchar(100) NOT NULL default '',
	PRIMARY KEY	(`id`),
	KEY `nombre` (`nombre`),
	KEY `apellido` (`apellido`)
) TYPE=InnoDB COMMENT='Autores' AUTO_INCREMENT=1 ;

INSERT INTO propano_autores (nombre, apellido, email) 
VALUES ('Adrian', 'Kosmaczewski', 'adrian@kosmaczewski.net');



DROP TABLE IF EXISTS `propano_articulos`;
CREATE TABLE `propano_articulos` (
	`id` int(10) unsigned NOT NULL auto_increment,
	`titulo` varchar(50) NOT NULL default '',
	`autor_id` int(10) unsigned NOT NULL default '0',
	`fecha_creacion` timestamp(14) NULL,
	`publico` bit NOT NULL default 0,
	PRIMARY KEY	(`id`),
	KEY `titulo` (`titulo`),
	KEY `autor_id` (`autor_id`)
) TYPE=InnoDB COMMENT='Articulos' AUTO_INCREMENT=1 ;

ALTER TABLE `propano_articulos`
ADD FOREIGN KEY (`autor_id`) REFERENCES propano_autores(`id`);

INSERT INTO propano_articulos (titulo, autor_id, publico)
VALUES ('titulo documento test', 1, 1);



DROP TABLE IF EXISTS `propano_articulo_versiones`;
CREATE TABLE `propano_articulo_versiones` (
	`id` int(10) unsigned NOT NULL auto_increment,
	`articulo_id` int(10) unsigned NOT NULL default '0',
	`resumen` varchar(200) NOT NULL default '',
	`contenidos` longtext NOT NULL,
	`autor_id` int(10) unsigned NOT NULL default '0',
	`fecha` timestamp(14) NULL,
	`publico` bit NOT NULL default 0,
	PRIMARY KEY	(`id`),
	KEY `articulo_id` (`articulo_id`),
	KEY `resumen` (`resumen`),
	KEY `autor_id` (`autor_id`)
) TYPE=InnoDB COMMENT='Versiones de articulos' AUTO_INCREMENT=1 ;

ALTER TABLE `propano_articulo_versiones`
ADD FOREIGN KEY (`articulo_id`) REFERENCES propano_articulos(`id`),
ADD FOREIGN KEY (`autor_id`) REFERENCES propano_autores(`id`);

INSERT INTO propano_articulo_versiones (articulo_id, resumen, contenidos, autor_id, publico)
VALUES (1, 'este es un resumen', '<h1>estos son contenidos TEST</h1> <pre>BOUH!</pre>', 1, 1);



DROP TABLE IF EXISTS `propano_estadisticas`;
CREATE TABLE `propano_estadisticas` (
	`id` int(10) unsigned NOT NULL auto_increment,
	`ip` char(15) NOT NULL default '',
	`articulo_version_id` int(10) unsigned NOT NULL default '0',
	`browser` varchar(200) NOT NULL default '',
	`fecha` datetime NOT NULL default '0000-00-00 00:00:00',
	PRIMARY KEY (`id`),
	KEY `fecha` (`fecha`),
	KEY `articulo_version_id` (`articulo_version_id`)
) TYPE=InnoDB Comment='Estadisticas de uso' AUTO_INCREMENT=1;

ALTER TABLE `propano_estadisticas`
ADD FOREIGN KEY (`articulo_version_id`) REFERENCES propano_articulo_versiones(`id`);
