<?php
/******************************************************************
Archivo database.php
Sistema Propano
"Dale gas..."
Autor: Adrian Kosmaczewski
Fecha: 05 de junio de 2004
Version: 1.0

Sistema Propano - Un sistema simple de gestion de contenidos web.
Copyright (C) 2004 - Adrian Kosmaczewski

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

NeXT, the NeXT Cube 	Logo, Objective-C and other related names
are trademarks of NeXT Software Inc. and/or Apple Computer Inc.

For more information please refer to:
http://www.apple.com/legal/nexttmlist.html
*/

require_once('configuracion.php');

/******************************************************************
Este archivo contiene un encapsulamiento de las funciones de acceso a base de
datos de MySQL en PHP. La sintaxis de uso de esta libreria es:

    require_once('database.php');
    
    $consulta = "SELECT nombre, apellido FROM clientes WHERE pais = 'Argentina'";
    $conjuntoRegistros = ejecutarConsulta($consulta);
    
    // El objeto $conjuntoRegistros expone tres metodos simples:
    //   cantidad(): devuelve la cantidad de resultados encontrados
    //   proximoRegistro(): devuelve la proxima linea de resultados, o "false" si no hay mas nada
    //   finalizar(): sirve para liberar la memoria usada por el recordset
    // y son usados de la manera siguiente:
    
    if ($conjuntoRegistros->cantidad() > 0)
    {
        while ($linea = $conjuntoRegistros->proximoRegistro())
        {
            $nombre = $linea['nombre'];
            $apellido = $linea['apellido'];
            echo("$nombre $apellido<br>");
        }
    }
    else
    {
        echo("No hay clientes en la base de datos.");
    }
    
    $conjuntoRegistros->finalizar();
*/

/******************************************************************
Clase Conexion
La clase Conexion hace una mimica de su equivalente en ADO.NET, con
la misma semantica y sintaxis, para conectarse a una base de datos MySQL.
Realiza un encapsulamiento orientado a objetos de las funciones de PHP
para conexion a MySQL.
*/    
class Conexion
{        
    var $servidor;
    var $usuario;
    var $password;
    var $database;
    var $conexion;

	/*
	Proposito: Constructor de la clase; inicializa los campos internos de la 
	           instancia con valores por defecto.
	Entrada:   Ninguno.
	Salida:    Ninguno.
	*/    
    function Conexion()
    {
        $this->servidor = $_SESSION['MySQL_Servidor'];
        $this->usuario = $_SESSION['MySQL_Usuario'];
        $this->password = $_SESSION['MySQL_Password'];
        $this->database = $_SESSION['MySQL_BaseDeDatos'];
    }

	/*
	Proposito: Abre la conexion a la base de datos.
	Entrada:   Ninguno.
	Salida:    Ninguno.
	*/
    function abrir()
    {
        $this->conexion = mysql_pconnect($this->servidor, $this->usuario, $this->password) 
            or trigger_error(mysql_error(), E_USER_ERROR);
    }
    
	/*
	Proposito: Realiza una consulta de tipo SELECT.
	Entrada:   Una consulta valida en SQL.
	Salida:    Una instancia de tipo ConjuntoRegistros.
	*/
    function ejecutarConsulta($consulta)
    {
        mysql_select_db($this->database, $this->conexion);
        $recordset = mysql_query($consulta, $this->conexion) or die(mysql_error());
        $conjuntoRegistros = new ConjuntoRegistros($recordset);
        return $conjuntoRegistros;
    }
    
	/*
	Proposito: Realiza una consulta de tipo INSERT, UPDATE o DELETE.
	Entrada:   Una consulta valida en SQL.
	Salida:    Ninguno.
	*/
    function ejecutarModificacion($consulta)
    {
        mysql_select_db($this->database, $this->conexion);
        $recordset = mysql_query($consulta, $this->conexion) or die(mysql_error());
    }
    
	/*
	Proposito: Cierra la conexion a la base de datos.
	Entrada:   Ninguno.
	Salida:    Ninguno.
	*/
    function cerrar()
    {
        $this->conexion = null;
    }
}

/******************************************************************
Clase ConjuntoRegistros
Encapsula el recordset producido por el acceso a la base de datos
MySQL con una sintaxis similar del objeto homonimo de .NET, similar a  
su vez al objeto ADODB.Recordset de ADO.
*/
class ConjuntoRegistros
{
    var $recordset;
    var $cantidad;
    
	/*
	Proposito: Constructor de la clase; inicializa los campos internos de la 
	           instancia con valores por defecto.
	Entrada:   Ninguno.
	Salida:    Ninguno.
	*/    
    function ConjuntoRegistros($rs)
    {
        $this->recordset = $rs;
        $this->cantidad = mysql_num_rows($rs);
    }
    
	/*
	Proposito: Devuelve el proximo registro del recordset. Si no hay mas
	           informaciones, devuelve "false" (util para bucles de tipo "while")
	Entrada:   Ninguno.
	Salida:    El proximo registro, en la forma de un array asociativo, o "false" si
	           no hay mas registros disponibles.
	*/    
    function proximoRegistro()
    {
        return mysql_fetch_assoc($this->recordset);
    }
    
	/*
	Proposito: Devuelve el numero de registros contenidos.
	Entrada:   Ninguno.
	Salida:    Un numero entero.
	*/    
    function cantidad()
    {
        return $this->cantidad;
    }
    
	/*
	Proposito: Libera la memoria retenida por los datos.
	Entrada:   Ninguno.
	Salida:    Ninguno.
	*/    
    function finalizar()
    {
        mysql_free_result($this->recordset);
        $this->recordset = null;
    }
}

/*
Proposito: Ejecuta una consulta de tipo SELECT, usando la clase Conexion.
           Esta funcion es una cortesia para evitar de tener esparcidos
           por todos lados en el codigo el mismo pedazo de codigo "new Conexion..." etc.
Entrada:   Una consulta valida SQL.
Salida:    Un objeto de tipo ConjuntoRegistros.
*/    
function ejecutarConsulta($consulta)
{
    $conn = new Conexion;
    $conn->abrir();
    $conjuntoRegistros = $conn->ejecutarConsulta($consulta);
    $conn->cerrar();
    return $conjuntoRegistros;
}

/*
Proposito: Ejecuta una consulta de tipo INSERT, UPDATE o DELETE, usando la clase Conexion.
           Esta funcion es una cortesia para evitar de tener esparcidos
           por todos lados en el codigo el mismo pedazo de codigo "new Conexion..." etc.
Entrada:   Una consulta valida SQL.
Salida:    Ninguno.
*/    
function ejecutarModificacion($consulta)
{
    $conn = new Conexion;
    $conn->abrir();
    $conjuntoRegistros = $conn->ejecutarModificacion($consulta);
    $conn->cerrar();
}

?>
