<?php
/******************************************************************
Archivo documento.php
Sistema Propano
"Dale gas..."
Autor: Adrian Kosmaczewski
Fecha: 08 de junio de 2004
Version: 1.0

Sistema Propano - Un sistema simple de gestion de contenidos web.
Copyright (C) 2004 - Adrian Kosmaczewski

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

NeXT, the NeXT Cube 	Logo, Objective-C and other related names
are trademarks of NeXT Software Inc. and/or Apple Computer Inc.

For more information please refer to:
http://www.apple.com/legal/nexttmlist.html
*/

/******************************************************************
Clase Documento
Esta clase representa los objetos que son devueltos de la base de 
datos a pedido de los clientes. Tambien se usa para la edicion de
articulos. Puede ser serializada en XML de manera muy basica,
siguiendo el esquema de los documentos XML del Sistema Propano.

Es inmutable: una vez que sus campos han sido rellenados no 
pueden ser editados.
*/
class Documento
{
	var $sId;
	var $sTitulo;
	var $sAutor;
	var $sFechaCreacion;
	var $sResumen;
	var $sContenidos;

	/*
	Proposito: Constructor: inicializa una nueva instancia con los
	           datos pasados en parametro.
	Entrada:   Los componentes de la instancia.
	Salida:    Ninguna.
	*/	
	function Documento($sId, $sTitulo, $sAutor, $sFechaCreacion, $sResumen, $sContenidos)
	{
		$this->sId = $sId;
		$this->sTitulo = $sTitulo;
		$this->sAutor = $sAutor;
		$this->sFechaCreacion = $sFechaCreacion;
		$this->sResumen = $sResumen;
		$this->sContenidos = $sContenidos;
	}
	
	/*
	Proposito: Devuelve el ID del documento.
	Entrada:   Ninguna.
	Salida:    Una cadena de texto.
	*/
	function obtenerId()
	{
		return $this->sId;
	}
	
	/*
	Proposito: Devuelve el titulo del documento.
	Entrada:   Ninguna.
	Salida:    Una cadena de texto.
	*/
	function obtenerTitulo()
	{
		return $this->sTitulo;
	}
	
	/*
	Proposito: Devuelve el autor del documento.
	Entrada:   Ninguna.
	Salida:    Una cadena de texto.
	*/
	function obtenerAutor()
	{
		return $this->sAutor;
	}
	
	/*
	Proposito: Devuelve la fecha de creacion del documento.
	Entrada:   Ninguna.
	Salida:    Una cadena de texto.
	*/
	function obtenerFechaCreacion()
	{
		return $this->sFechaCreacion;
	}
	
	/*
	Proposito: Devuelve el resumen del documento.
	Entrada:   Ninguna.
	Salida:    Una cadena de texto.
	*/
	function obtenerResumen()
	{
		return $this->sResumen;
	}
	
	/*
	Proposito: Devuelve el contenido del documento.
	Entrada:   Ninguna.
	Salida:    Una cadena de texto.
	*/
	function obtenerContenidos()
	{
		return $this->sContenidos;
	}
	
	/*
	Proposito: Serializa esta instancia en una cadena en XML con el esquema
	           de los documentos del sistema Propano. Este XML puede ser usado
	           por los clientes del Sistema Propano que tienen soporte para
	           el componente XmlHttpRequest (Mozilla, Safari e Internet Explorer Windows).
	Entrada:   Ninguna.
	Salida:    Una cadena de texto en formato XML valido.
	*/
	function serializarEnXML()
	{
		$sId = $this->sId;
		$sTitulo = $this->sTitulo;
		$sAutor = $this->sAutor;
		$sFecha = $this->sFechaCreacion;
		$sResumen = $this->sResumen;
		$sContenidos = $this->sContenidos;
		
		return vsprintf('<?xml version="1.0" encoding="UTF-8"?><documento id="%s"><metadatos><titulo>%s</titulo><autor>%s</autor><fecha>%s</fecha></metadatos><datos><resumen><![CDATA[%s]]></resumen><contenidos><![CDATA[%s]]></contenidos></datos></documento>', $sId, $sTitulo, $sAutor, $sFecha, $sResumen, $sContenidos);
	}
}

?>