<?php
/******************************************************************
Archivo mail.php
Sistema Propano
"Dale gas..."
Autor: Adrian Kosmaczewski
Fecha: 05 de junio de 2004
Version: 1.0

Sistema Propano - Un sistema simple de gestion de contenidos web.
Copyright (C) 2004 - Adrian Kosmaczewski

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

NeXT, the NeXT Cube 	Logo, Objective-C and other related names
are trademarks of NeXT Software Inc. and/or Apple Computer Inc.

For more information please refer to:
http://www.apple.com/legal/nexttmlist.html
*/

/******************************************************************
Clase Mail
Esta clase encapsula las funciones de e-mail de PHP para que sean mas intuitivas de uso.
Esta primera version solamente acepta un solo destinatario. Los mensajes tienen el formato 
HTML por defecto, pero se puede hacer que se mande como Texto.

Tambien se le puede solicitar que chequee la existencia del email en el servidor
remoto antes de enviar el mensaje. Esto puede ser util...

Este es un ejemplo de uso:

	$mail = new Mail();
	$mail->ponerRemitente("remitente@servidor.com");
	$mail->ponerDestinatario("destinatario@otroservidor.net");
	$mail->ponerTitulo("Titulo del mensaje");
	$mail->ponerCuerpoDelMensaje("Hola! Que tal?");
	$mail->mandarComoHTML(true);
	
	// Enviar el mensaje solo si existe el destinatario
	if ($mail->existeDestinatario())
	{
		$mail->enviar();
	}
	else
	{
		header("location: invalidoemail.html");
	}
	$mail = null;
	
	// Redirigir el usuario hacia otra pagina
	header("location: success.html");

NOTA: si bien esta clase tiene interfaces listas para agregar copia y copia oculta (CC y BCC),
actualmente no es posible usar esta clase para tales propositos. Se deja estos metodos
para futuros desarrollos.	
*/
class Mail
{
	var $sRemitente;
	var $sDestinatario;
	var $sCopia;
	var $sCopiaOculta;
	var $sTitulo;
	var $sCuerpoDelMensaje;
	var $bFormatoHTML;

	/*
	Proposito: Constructor de la case. Inicializa las variables a sus
	           valores por defecto.
	Entrada:   Ninguna.
	Salida:    Una nueva instancia.
	*/
	function Mail()
	{
		$this->sRemitente = "";
		$this->sDestinatario = "";
		$this->sCopia = "";
		$this->sCopiaOculta = "";
		$this->sTitulo = "";
		$this->sCuerpoDelMensaje = "";
		$this->bFormatoHTML = true;
	}

	/*
	Proposito: Agrega el remitente del mensaje.
	Entrada:   Una cadena de texto con un e-mail valido.
	Salida:    Ninguna.
	*/
	function ponerRemitente($sParametro)
	{
		$this->sRemitente = $sParametro;
	}

	/*
	Proposito: Agrega el destinatario del mensaje.
	Entrada:   Una cadena de texto con un e-mail valido.
	Salida:    Ninguna.
	*/
	function ponerDestinatario($sParametro)
	{
		$this->sDestinatario = $sParametro;
	}
	
	/*
	Proposito: Agrega un destinatario para una copia (CC) del mensaje.
	Entrada:   Una cadena de texto con un e-mail valido.
	Salida:    Ninguna.
	*/
	function ponerCopia($sParametro)
	{
		$this->sCopia = $sParametro;
	}
	
	/*
	Proposito: Agrega un destinatario para una copia (BCC) del mensaje.
	Entrada:   Una cadena de texto con un e-mail valido.
	Salida:    Ninguna.
	*/
	function ponerCopiaOculta($sParametro)
	{
		$this->sCopiaOculta = $sParametro;
	}
	
	/*
	Proposito: Agrega el titulo del mensaje.
	Entrada:   Una cadena de texto con un e-mail valido.
	Salida:    Ninguna.
	*/
	function ponerTitulo($sParametro)
	{
		$this->sTitulo = $sParametro;
	}

	/*
	Proposito: Agrega el cuerpo del mensaje.
	Entrada:   Una cadena de texto con un e-mail valido.
	Salida:    Ninguna.
	*/
	function ponerCuerpoDelMensaje($sParametro)
	{
		$this->sCuerpoDelMensaje = $sParametro;
	}
	
	/*
	Proposito: Determina si el mensaje sera enviado como HTML o "Plain Text"
	Entrada:   Un valor booleano; si es "true", el mensaje se envia como HTML.
	Salida:    Ninguna.
	*/
	function mandarComoHTML($bParametro)
	{
		$this->bFormatoHTML = $bParametro;
	}

	/*
	Proposito: Determina si existe el email del destinatario. Puede ser
	           util para ser usado en el caso en que el destinatario
	           es puesto dinamicamente por usuarios de una pagina web...
	Entrada:   Ninguna.
	Salida:    "true" si existe el email, "false" si no existe.
	*/
	function existeDestinatario()
	{
		if ($this->sDestinatario != "")
		{
			$aPartes = explode("@", $this->sDestinatario);
			$sServidor = $aPartes[1];
			$sUsuario = $aPartes[0];
			$oConexion = fsockopen($sServidor, 25);
			set_socket_blocking($oConexion, true);
			fputs($oConexion, "Helo Local\n");
			fgets($oConexion, 2000);
			fgets($oConexion, 2000);
			fputs($oConexion, "Mail From:<$sUsuario@$sServidor> \n");
			fgets($oConexion, 2000);
			fputs($oConexion, "RCPT to:aetos<$sUsuario@$sServidor> \n");
			$oResultado = fgets($oConexion, 2000);
			$sCodigo = substr($oResultado, 0, 3);
			if ($sCodigo == 250)
			{
				return true;
			}
			else
			{
				return false;
			}
		}
	}

	/*
	Proposito: Envia el mensaje usando los parametros especificados.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	function enviar()
	{
		if ($this->bFormatoHTML)
		{
			$sCabeceras = "MIME-Version: 1.0\r\n";
			$sCabeceras .= "Content-type: text/html; charset=iso-8859-1\r\n";
		}

		$sCabeceras .= "To: $sDestinatario\r\n";
		$sCabeceras .= "From: $sRemitente\r\n";
		
		if ($this->sCopia != "")
		{
			$sCabeceras .= "Cc: $sCopia\r\n";
		}
		
		if ($this->sCopiaOculta != "")
		{
			$sCabeceras .= "Bcc: $sCopiaOculta\r\n";
		}

		// Esta es la funcion PHP que sirve para mandar e-mail.
		mail($this->sDestinatario, $this->sTitulo, $this->sCuerpoDelMensaje, $sCabeceras);
	}
}
?>
