<?php
/******************************************************************
Archivo xslt.php
Sistema Propano
"Dale gas..."
Autor: Adrian Kosmaczewski
Fecha: 05 de junio de 2004
Version: 1.0

Sistema Propano - Un sistema simple de gestion de contenidos web.
Copyright (C) 2004 - Adrian Kosmaczewski

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

NeXT, the NeXT Cube 	Logo, Objective-C and other related names
are trademarks of NeXT Software Inc. and/or Apple Computer Inc.

For more information please refer to:
http://www.apple.com/legal/nexttmlist.html
*/

/******************************************************************
Clase XSLT
Esta clase encapsula y facilita el acceso a la funcion de transformacion
XSLT de PHP. Se le pueden pasar nombres de archivos o bien una cadena de 
texto con los datos XML dentro.

Ejemplo de uso:

	$section = 'sc';
	$place = 'us';
	$lang = 'en';
	$params = array ('section' => $section, 'place' => $place, 'lang' => $lang);
	
	$xslt = new XSLT;
	$xslt->archivoXML('test.xml');
	$xslt->archivoXSL('test.xsl');
	$xslt->agregarParametros($params);
	$resultado = $xslt->transformar();
	$xslt->finalizar();

NOTA: parece que en PHP 5.0 la sintaxis para las transformaciones PHP cambia; 
este es un fragmento de http://ch.php.net/xslt_process

	The xslt_ functions no longer work in PHP/5.0; the XSLT extension has been removed. 
	To apply an XSL transformation to an XML document, you must use DomDocument 
	(from DOM) and XsltProcessor (from XSL):
	
	<?
	$xml = new DomDocument();
	$xml->load('foo.xml');
	                                       
	$xsl = new DomDocument;
	$xsl->load('foo.xsl');
	                                       
	$proc = new xsltprocessor();
	$proc->importStyleSheet($xsl);
	echo($proc->transformToXML($xml));
	?>
*/
class XSLT
{
	var $oMotor;
	var $bUsaArchivoXML;
	var $bUsaArchivoXSL;
	var $aParametros;
	var $sArchivoXML;
	var $sArchivoXSL;
	var $sXML;
	var $sXSL;
	
	/*
	Proposito: Constructor. Inicializa los campos internos de la instancia.
	Entrada:   Ninguna.
	Salida:    Una nueva instancia.
	*/
	function XSLT()
	{
		$this->oMotor = xslt_create();
		$this->aParametros = array();
		$this->bUsaArchivoXML = true;
		$this->bUsaArchivoXSL = true;
		$this->sXML = "";
		$this->sXSL = "";
	}

	/*
	Proposito: Proporciona el camino de acceso al archivo XML que sera transformado.
	Entrada:   Una cadena de texto con un camino valido de acceso.
	Salida:    Ninguna.
	*/
	function archivoXML($sParametro)
	{
		$this->sArchivoXML = $sParametro;
		$this->bUsaArchivoXML = true;
	}

	/*
	Proposito: Proporciona el camino de acceso al archivo XSL que se usara
	           en la transformacion.
	Entrada:   Una cadena de texto con un camino valido de acceso.
	Salida:    Ninguna.
	*/
	function archivoXSL($sParametro)
	{
		$this->sArchivoXSL = $sParametro;
		$this->bUsaArchivoXSL = true;
	}
	
	/*
	Proposito: Proporciona la cadena de texto con el flujo XML que sera transformado.
	Entrada:   Una cadena de texto en formato XML valido.
	Salida:    Ninguna.
	*/
	function cadenaXML($sParametro)
	{
		$this->sXML = $sParametro;
		$this->bUsaArchivoXML = false;
	}

	/*
	Proposito: Proporciona la cadena de texto con el flujo
	           XSL que se usara en la transformacion.
	Entrada:   Una cadena de texto en formato XSL valido.
	Salida:    Ninguna.
	*/
	function cadenaXSL($sParametro)
	{
		$this->sXSL = $sParametro;
		$this->bUsaArchivoXSL = false;
	}

	/*
	Proposito: Agrega un arreglo de parametros para ser usados en la transformacion.
	Entrada:   Un arreglo.
	Salida:    Ninguna.
	*/
	function agregarParametros($aParametro)
	{
		$this->aParametros = $aParametro;
	}

	/*
	Proposito: Realiza la transformacion propiamente dicha.
	Entrada:   Ninguna.
	Salida:    Una cadena de texto con el flujo XML (o no)
	           resultante de la transformacion.
	*/
	function transformar()
	{
		$aArgumentos = array('/_xml' => $this->sXML, '/_xsl' => $this->sXSL);
		$sXML = ($this->bUsaArchivoXML) ? $this->sArchivoXML : 'arg:/_xml';
		$sXSL = ($this->bUsaArchivoXSL) ? $this->sArchivoXSL : 'arg:/_xsl';
		$sResultado = xslt_process($this->oMotor, $sXML, $sXSL, NULL, $aArgumentos, $this->aParametros);
		if ($sResultado) 
		{
			return $sResultado;
		}
		else 
		{
			$error = "Error durante la transformacion XSLT; ";
			$error .= "error: " . xslt_error($this->oMotor) . "; error code: " . xslt_errno($this->oMotor);
			return $error;
		}		
	}
	
	/*
	Proposito: Libera la memoria usada para la transformacion.
	Entrada:   Ninguna.
	Salida:    Ninguna.
	*/
	function finalizar()
	{
		xslt_free($this->oMotor);		
	}
}

?>
